pub enum LineCap {
Butt,
Square,
Round,
}Expand description
Specifies how to render the endpoints of the path when stroking.
Variants
Butt
Start (and stop) the line exactly at the start (end) point.
Square
Use squared ending, the center of the square is the end point.
Round
Use a round ending, the center of the circle is the end point.